@@ -1,8 +1,7 @@
 #!/bin/sh
 #
-# $Id: autogen.sh 23241 2006-09-29 19:05:15Z kelnos $
 #
-# Copyright (c) 2002-2008
+# Copyright (c) 2002-2020
 #         The Xfce development team. All rights reserved.
 #
 # Written for Xfce by Benedikt Meurer <benny@xfce.org>.
@@ -12,12 +11,12 @@
   cat >&2 <<EOF
 autogen.sh: You don't seem to have the Xfce development tools installed on
             your system, which are required to build this software.
-            Please install the xfce4-dev-tools package first, available from
-            http://xfce.org/~benny/projects/xfce4-dev-tools/.
+            Please install the xfce4-dev-tools package first, it is available
+            from your distribution or https://www.xfce.org/.
 EOF
   exit 1
 }
 
-XDT_AUTOGEN_REQUIRED_VERSION="4.7.0" xdt-autogen "$@"
+XDT_AUTOGEN_REQUIRED_VERSION="4.14.0" xdt-autogen "$@"
 
 # vi:set ts=2 sw=2 et ai:
