@@ -37,6 +37,13 @@
 
 #include "xfce-notify-log.h"
 
+static void
+notify_free (guchar *pixels,
+             gpointer data)
+{
+  g_free (pixels);
+}
+
 GdkPixbuf *
 notify_pixbuf_from_image_data (GVariant *image_data)
 {
@@ -79,14 +86,14 @@ notify_pixbuf_from_image_data (GVariant *image_data)
                                    GDK_COLORSPACE_RGB, has_alpha,
                                    bits_per_sample, width, height,
                                    rowstride,
-                                   (GdkPixbufDestroyNotify)g_free, NULL);
+                                   notify_free, NULL);
     return pix;
 }
 
-const gchar *
+gchar *
 notify_icon_name_from_desktop_id (const gchar *desktop_id)
 {
-    const gchar *icon_file;
+    gchar *icon_file = NULL;
     gchar *resource;
     XfceRc *rcfile;
 
@@ -96,14 +103,17 @@ notify_icon_name_from_desktop_id (const gchar *desktop_id)
     rcfile = xfce_rc_config_open(XFCE_RESOURCE_DATA,
                                  resource, TRUE);
     g_free (resource);
-    if (rcfile && xfce_rc_has_group (rcfile, "Desktop Entry")) {
-        xfce_rc_set_group (rcfile, "Desktop Entry");
-        icon_file = xfce_rc_read_entry (rcfile, "Icon", NULL);
+    if (rcfile)
+    {
+        if (xfce_rc_has_group (rcfile, "Desktop Entry"))
+        {
+            xfce_rc_set_group (rcfile, "Desktop Entry");
+            icon_file = g_strdup (xfce_rc_read_entry (rcfile, "Icon", NULL));
+            /* At this point: icon_file might be NULL */
+        }
         xfce_rc_close (rcfile);
-        return icon_file;
     }
-    else
-        return NULL;
+    return icon_file;
 }
 
 GKeyFile *
@@ -127,12 +137,36 @@ xfce_notify_log_get (void)
     return notify_log;
 }
 
+/* Based on: https://gitlab.gnome.org/GNOME/glib/-/blob/master/glib/gdatetime.c */
+static gchar *
+date_time_format_iso8601 (GDateTime *datetime)
+{
+    const gdouble seconds = g_date_time_get_seconds (datetime);
+    gchar *format, *main_date, *time_zone, *outstr;
+
+    format = (seconds == (glong) seconds) ? "%Y-%m-%dT%H:%M:%S" : "%Y-%m-%dT%H:%M:%S.%f";
+
+    main_date = g_date_time_format (datetime, format);
+
+    if (g_date_time_get_utc_offset (datetime) == 0) {
+        time_zone = g_strdup ("Z");
+    }
+    else {
+        time_zone = g_date_time_format (datetime, "%:::z");
+    }
+
+    outstr = g_strconcat (main_date, time_zone, NULL);
+    g_free (main_date);
+    g_free (time_zone);
+    return outstr;
+}
+
 static void
 xfce_notify_log_keyfile_insert1 (GKeyFile *notify_log,
                                  const gchar *app_name,
                                  const gchar *summary,
                                  const gchar *body,
-                                 GVariant *image_data,
+                                 GVariant *v_image_data,
                                  const gchar *image_path,
                                  const gchar *app_icon,
                                  const gchar *desktop_id,
@@ -151,23 +185,23 @@ xfce_notify_log_keyfile_insert1 (GKeyFile *notify_log,
                                                          XFCE_NOTIFY_ICON_PATH, TRUE);
 
     now = g_date_time_new_now_local ();
-    timestamp = g_date_time_format_iso8601 (now);
+    timestamp = date_time_format_iso8601 (now);
     g_date_time_unref (now);
-    group = g_strdup_printf ("%s", timestamp);
+    group = g_strdup (timestamp);
     g_free(timestamp);
 
     g_key_file_set_string (notify_log, group, "app_name", app_name);
     g_key_file_set_string (notify_log, group, "summary", summary);
     g_key_file_set_string (notify_log, group, "body", body);
-    if (image_data) {
+    if (v_image_data) {
         GBytes *image_bytes;
         gchar *icon_name;
         GdkPixbuf *pixbuf;
 
-        image_bytes = g_variant_get_data_as_bytes (image_data);
+        image_bytes = g_variant_get_data_as_bytes (v_image_data);
         icon_name = g_compute_checksum_for_bytes (G_CHECKSUM_SHA1, image_bytes);
         g_bytes_unref(image_bytes);
-        pixbuf = notify_pixbuf_from_image_data (image_data);
+        pixbuf = notify_pixbuf_from_image_data (v_image_data);
         if (pixbuf) {
             gchar *notify_log_icon_path = g_strconcat (notify_log_icon_folder , icon_name, ".png", NULL);
             if (!g_file_test (notify_log_icon_path, G_FILE_TEST_EXISTS)) {
@@ -220,7 +254,9 @@ xfce_notify_log_keyfile_insert1 (GKeyFile *notify_log,
         g_key_file_set_string (notify_log, group, "app_icon", app_icon);
     }
     else if (desktop_id) {
-        g_key_file_set_string (notify_log, group, "app_icon", notify_icon_name_from_desktop_id(desktop_id));
+        gchar *icon_name = notify_icon_name_from_desktop_id (desktop_id);
+        g_key_file_set_string (notify_log, group, "app_icon", icon_name);
+        g_free (icon_name);
     }
 
     timeout = g_strdup_printf ("%d", expire_timeout);
@@ -362,37 +398,43 @@ void xfce_notify_log_insert (const gchar *app_name,
     g_free (notify_log_path);
 }
 
-gchar *
+/* Returns NULL if unable to determine the icon cache size */
+static gchar *
 xfce_notify_get_icon_cache_size (void)
 {
-    gchar *notify_icon_cache_path = NULL;
-    gchar *size_string;
+    gchar *notify_icon_cache_path;
 
     notify_icon_cache_path = xfce_resource_save_location (XFCE_RESOURCE_CACHE,
                                                           XFCE_NOTIFY_ICON_PATH, FALSE);
     if (notify_icon_cache_path)
     {
         GFile *icon_folder;
-        guint64 disk_usage, num_dirs, num_files;
+        guint64 disk_usage, num_files;
+        gboolean status;
 
         icon_folder = g_file_new_for_path (notify_icon_cache_path);
+        g_free (notify_icon_cache_path);
+        notify_icon_cache_path = NULL;
 
-        g_file_measure_disk_usage (icon_folder,
+        status = g_file_measure_disk_usage (icon_folder,
                                    G_FILE_MEASURE_NONE,
                                    NULL, NULL, NULL,
                                    &disk_usage,
-                                   &num_dirs,
+                                   NULL,
                                    &num_files,
                                    NULL);
-        size_string = g_strdup_printf ("%d icons / %.1lf MB",
-                                       (int) num_files, (gdouble) disk_usage / 1000000);
         g_object_unref (icon_folder);
+        icon_folder = NULL;
+
+        if (status == TRUE) {
+            return g_strdup_printf ("%d icons / %.1f MB", (int) num_files, disk_usage / 1e6);
+        }
     }
-    g_free (notify_icon_cache_path);
-    return size_string;
+
+    return NULL;
 }
 
-void xfce_notify_clear_icon_cache (void)
+static void xfce_notify_clear_icon_cache (void)
 {
     gchar *notify_icon_cache_path = NULL;
 
@@ -476,7 +518,7 @@ GtkWidget *xfce_notify_clear_log_dialog (void)
 {
     GtkWidget *dialog, *grid, *icon, *label, *content_area, *checkbutton;
     GtkDialogFlags flags = GTK_DIALOG_MODAL;
-    gchar *message;
+    gchar *icon_cache_size;
     const char *str = _("Do you really want to clear the notification log?");
     const char *format = "<span weight='bold' size='large'>%s</span>";
     char *markup;
@@ -499,14 +541,24 @@ GtkWidget *xfce_notify_clear_log_dialog (void)
 
     icon = gtk_image_new_from_icon_name ("edit-clear", GTK_ICON_SIZE_DIALOG);
 
-    message = g_strdup_printf ("%s (%s)",_("include icon cache"), xfce_notify_get_icon_cache_size ());
+    icon_cache_size = xfce_notify_get_icon_cache_size ();
+    if (icon_cache_size)
+    {
+        gchar *message = g_strdup_printf ("%s (%s)", _("include icon cache"), icon_cache_size);
+        g_free (icon_cache_size);
+        icon_cache_size = NULL;
+        checkbutton = gtk_check_button_new_with_label (message);
+        g_free (message);
+    }
+    else
+    {
+        checkbutton = gtk_check_button_new_with_label (_("include icon cache"));
+    }
     label = gtk_label_new (NULL);
     markup = g_markup_printf_escaped (format, str);
     gtk_label_set_markup (GTK_LABEL (label), markup);
     g_free (markup);
 
-    checkbutton = gtk_check_button_new_with_label (message);
-
     gtk_grid_attach (GTK_GRID (grid), icon, 0, 0, 1, 2);
     gtk_grid_attach (GTK_GRID (grid), label, 1, 0, 1, 1);
     gtk_grid_attach (GTK_GRID (grid), checkbutton, 1, 1, 1, 1);
